@@ -191,6 +191,11 @@ class TaskLoop:
     def task_continue(self):
         self.control = "CONTINUE"
 
+
+    def finish(self, finish=print):
+        self.active_task.remove_done_callback(self.done_callback)
+        self.add_done_callback(finish)
+
     @property
     def name(self):
         return self._name
@@ -206,8 +211,12 @@ class TaskLoop:
                     self.coro_args,
                     self.coro_kwargs,
                     self.fargs))
-            task.add_done_callback(
-                 functools.partial(self.renew, task, self.coro, self.fargs))
+            self.done_callback = functools.partial(
+                self.renew, task, 
+                self.coro,
+                self.fargs)
+            task.add_done_callback(self.done_callback)
+            self.active_task = task
             return task
         if VERSION.major == 3 and VERSION.minor == 7:
             task = self.loop.create_task(
@@ -216,8 +225,13 @@ class TaskLoop:
                     self.coro_args,
                     self.coro_kwargs,
                     self.fargs))
-            task.add_done_callback(
-                 functools.partial(self.renew, task, self.coro, self.fargs))
+
+            self.done_callback = functools.partial(
+                self.renew, task, 
+                self.coro,
+                self.fargs)
+            task.add_done_callback(self.done_callback)
+            self.active_task = task
             return task
 
 
